==> brmo-stufbg204-1.6.1-sources.jar: nl/egem/stuf/sector/bg/_0204/ADRRelKerngegevens.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * template relatie entiteit voor een relatie met een adres als gerelateerde met alleen kerngegevens
 * 
 * <p>Java class for ADR-relKerngegevens complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ADR-relKerngegevens">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *       &lt;sequence>
 *         &lt;element name="ADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-fund"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ADR-relKerngegevens", propOrder = {
    "adr"
})
@XmlSeeAlso({
    nl.egem.stuf.sector.bg._0204.WOZKerngegevens.WOZADRHFD.class,
    PRSADRVBL.class,
    nl.egem.stuf.sector.bg._0204.NNPKerngegevens.NNPADRVBL.class,
    nl.egem.stuf.sector.bg._0204.VBOKerngegevens.VBOADR.class
})
public class ADRRelKerngegevens
    extends Relatie
{

    @XmlElement(name = "ADR", required = true, nillable = true)
    protected ADRFund adr;

    /**
     * Gets the value of the adr property.
     * 
     * @return
     *     possible object is
     *     {@link ADRFund }
     *     
     */
    public ADRFund getADR() {
        return adr;
    }

    /**
     * Sets the value of the adr property.
     * 
     * @param value
     *     allowed object is
     *     {@link ADRFund }
     *     
     */
    public void setADR(ADRFund value) {
        this.adr = value;
    }

}

==> brmo-stufbg204-2.0.0-sources.jar: nl/egem/stuf/sector/bg/_0204/ADRRelKerngegevens.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * template relatie entiteit voor een relatie met een adres als gerelateerde met alleen kerngegevens
 * 
 * <p>Java class for ADR-relKerngegevens complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ADR-relKerngegevens"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="ADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-fund"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ADR-relKerngegevens", propOrder = {
    "adr"
})
@XmlSeeAlso({
    nl.egem.stuf.sector.bg._0204.NNPKerngegevens.NNPADRVBL.class,
    PRSADRVBL.class,
    nl.egem.stuf.sector.bg._0204.VBOKerngegevens.VBOADR.class,
    nl.egem.stuf.sector.bg._0204.WOZKerngegevens.WOZADRHFD.class
})
public class ADRRelKerngegevens
    extends Relatie
{

    @XmlElement(name = "ADR", required = true, nillable = true)
    protected ADRFund adr;

    /**
     * Gets the value of the adr property.
     * 
     * @return
     *     possible object is
     *     {@link ADRFund }
     *     
     */
    public ADRFund getADR() {
        return adr;
    }

    /**
     * Sets the value of the adr property.
     * 
     * @param value
     *     allowed object is
     *     {@link ADRFund }
     *     
     */
    public void setADR(ADRFund value) {
        this.adr = value;
    }

}
